AddonName = "PetShoppingList"
PetShoppingList = LibStub("AceAddon-3.0"):NewAddon(AddonName, "AceEvent-3.0", "AceConsole-3.0", "AceHook-3.0")
local L = LibStub("AceLocale-3.0"):GetLocale(AddonName)
local LibPetJournal = LibStub("LibPetJournal-2.0")

PetShoppingList.missingIDs = {}
PetShoppingList.missingNames = {}

function PetShoppingList:OnInitialize()
end

function PetShoppingList:OnEnable()
	LibPetJournal.RegisterCallback(self, "PetListUpdated", "UpdateShoppingList")
	self:RegisterChatCommand("petshoppinglist", "SlashPetShoppingList")
end

function PetShoppingList:OnDisable()
end




function PetShoppingList:UpdateMissingPetsList()
   local tradeableIDs = {}
   for _,speciesID in LibPetJournal:IterateSpeciesIDs() do 
      speciesName, speciesIcon, petType, companionID, tooltipSource, tooltipDescription, isWild, canBattle, isTradeable, isUnique, obtainable, creatureDisplayID = C_PetJournal.GetPetInfoBySpeciesID(speciesID)
      if (isTradeable) then
         table.insert(tradeableIDs, speciesID)
      end
   end
   
   local ownedIDs = {}
   for _,PetID in LibPetJournal:IteratePetIDs() do 
      local speciesID = C_PetJournal.GetPetInfoByPetID(PetID)
      table.insert(ownedIDs, speciesID)
   end
   
   table.sort(ownedIDs)
   table.sort(tradeableIDs)
   
   PetShoppingList.missingIDs = {}
   PetShoppingList.missingNames = {}
   for i, v in ipairs(tradeableIDs) do
      found = false
      for j, x in ipairs(ownedIDs) do
         if (v==x) then
            found = true
            break
         end
      end
      if (found == false) then
         table.insert(PetShoppingList.missingIDs, v)
         speciesName, speciesIcon, petType, companionID, tooltipSource, tooltipDescription, isWild, canBattle, isTradeable, isUnique, obtainable, creatureDisplayID = C_PetJournal.GetPetInfoBySpeciesID(v)
         table.insert(PetShoppingList.missingNames, speciesName)
      end
   end
   
   table.sort(PetShoppingList.missingIDs)
   table.sort(PetShoppingList.missingNames)
   
end


function PetShoppingList:UpdateShoppingList()
	
	self:UpdateMissingPetsList()

	if (AuctionatorLoaded) then
		local slist = Atr_SList.FindByName("Missing Battle Pets", nil)
		if (not slist) then
		  slist = Atr_SList.create("Missing Battle Pets", false, true)
		end
		slist:Clear()

		for i, v in ipairs(PetShoppingList.missingNames) do
		  slist:AddItem (v)
		end
		Atr_Onclick_SaveTempList()  
--		print ("|cff1eff00Auctionator |cffffffffShopping List updated:", #PetShoppingList.missingNames, "|cffffffffmissing cageable Battle Pets!")
	end
	
--	if (SomeOtherAuctionAddonExists) then
--	
--	end

end


function PetShoppingList:GeneratePlainTextList()

	self:UpdateMissingPetsList()

	local missingNamesText = ""
	for i, v in ipairs(PetShoppingList.missingNames) do
		missingNamesText = missingNamesText .. v .. "\r\n"
	end

	return missingNamesText
	
end


function PetShoppingList:SlashPetShoppingList()
   local missingNamesText = self:GeneratePlainTextList()
   
   local AceGUI = LibStub("AceGUI-3.0")
   
   local frame = AceGUI:Create("Frame")
   frame:SetTitle("Missing Tradeable Battle Pets")
   frame:SetStatusText(tostring(#PetShoppingList.missingNames) .. " missing pets")
   frame:SetWidth(300)
   frame:SetLayout("Fill")
   
   local editbox = AceGUI:Create("MultiLineEditBox")
   editbox:SetLabel("")
   editbox:SetText(missingNamesText)
   frame:AddChild(editbox)
end